package cc.toph.simplycompat.item;

import com.google.common.base.Suppliers;
import java.util.function.Supplier;
import net.minecraft.item.Item;
import net.minecraft.item.Items;
import net.minecraft.item.ToolMaterial;
import net.minecraft.recipe.Ingredient;

public enum SimplyCompatToolMaterials implements ToolMaterial {
  COPPER(1, 125, 4.5F, 1.0F, 8, Items.COPPER_INGOT),
  STEEL(2, 600, 6.5F, 2.5F, 12, Items.DIAMOND);

  private final int miningLevel;
  private final int itemDurability;
  private final float miningSpeed;
  private final float attackDamage;
  private final int enchantability;
  private final Supplier<Ingredient> repairIngredient;

  SimplyCompatToolMaterials(
    int miningLevel,
    int itemDurability,
    float miningSpeed,
    float attackDamage,
    int enchantability,
    Item... repairIngredient
  ) {
    this.miningLevel = miningLevel;
    this.itemDurability = itemDurability;
    this.miningSpeed = miningSpeed;
    this.attackDamage = attackDamage;
    this.enchantability = enchantability;
    this.repairIngredient = Suppliers.memoize(() -> Ingredient.ofItems(repairIngredient));
  }

  @Override
  public int getDurability() {
    return this.itemDurability;
  }

  @Override
  public float getMiningSpeedMultiplier() {
    return this.miningSpeed;
  }

  @Override
  public float getAttackDamage() {
    return this.attackDamage;
  }

  @Override
  public int getMiningLevel() {
    return this.miningLevel;
  }

  @Override
  public int getEnchantability() {
    return this.enchantability;
  }

  @Override
  public Ingredient getRepairIngredient() {
    repairIngredient.get().getMatchingItemIds();
    return this.repairIngredient.get();
  }

  public void getIdenfier() {
    System.out.println(this.repairIngredient.get().toJson().getAsString());
  }
}
